@@ -4,6 +4,7 @@
 #include <QMainWindow>
 #include <QtGui>
 #include "xml.h"
+#include "historyinfowindow.h"
 
 class DayHistory : public QMainWindow
 {
@@ -15,11 +16,15 @@ public:
 
 private:
     XML *xml;
+    HistoryInfoWindow *hiw;
 
     QListView *lstExercises;
     QList < QList <QString> > exercises;
     QStandardItemModel *model;
 
+private slots:
+    void showInfo(QModelIndex index);
+
 };
 
-#endif // DAYHISTORY_H
+#endif //DAYHISTORY_H
