@@ -3,6 +3,7 @@
 HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
     QMainWindow(parent)
 {
+    QString set;
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
     QWidget *widget = new QWidget();
@@ -10,7 +11,8 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
 
     for(int i = 0; i < 9; i++)
     {
-        lblSet[i] = new QLabel();
+        set.setNum(i);
+        lblSet[i] = new QLabel("Set " + set + ": No info.");
         vLayout->addWidget(lblSet[i]);
     }
 
@@ -31,9 +33,6 @@ void HistoryInfoWindow::load(QString name, QString group)
 
     list = xml->getHistoryByExercise(name);
 
-    for(int i = 0; i < 9; i++)
-        lblSet[i]->setText("");
-
     while(!list.isEmpty())
     {
         set.setNum(j+1);
