@@ -6,6 +6,7 @@
 #include <QtGui>
 #include "xml.h"
 #include "dayhistory.h"
+#include "qmaemo5rotator.h"
 
 //class ListWindow;
 //class FoodWindow;
@@ -17,7 +18,7 @@ class HistoryWindow : public QMainWindow
 public:
     explicit HistoryWindow(QWidget *parent = 0);
     void load();
-
+    QMaemo5Rotator *hwRot;
 
 private:
     DayHistory *dh;
