@@ -212,9 +212,9 @@ void InfoWindow::loadExercise(QString name)
 
     while(!list.isEmpty())
     {
-        status[i] = list.takeFirst(); //remove status
-        reps[i] = list.takeFirst();
         weight[i] = list.takeFirst();
+        reps[i] = list.takeFirst();
+        status[i] = list.takeFirst();
 
         i++;
     }
@@ -275,17 +275,20 @@ void InfoWindow::forward()
             str = "/home/user/.qexercise/Images/" + exerciseName + "2.png";
             str.replace(QString(" "), QString(""));
 
-            bild.load(str);
+
             if(!bild.load(str))
             {
                 i = 2;
                 forward();
                 return;
             }
-            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
-            lblInfo->setAlignment(Qt::AlignCenter);
-            lblInfo->setPixmap(bild);
-            i++;
+            else
+            {
+                bild = bild.scaled(w,h,Qt::KeepAspectRatio);
+                lblInfo->setAlignment(Qt::AlignCenter);
+                lblInfo->setPixmap(bild);
+                i++;
+            }
             //}
          return;
     }
@@ -302,17 +305,20 @@ void InfoWindow::forward()
             str = "/home/user/.qexercise/Images/" + exerciseName + "1.png";
             str.replace(QString(" "), QString(""));
 
-            bild.load(str);
+
             if(!bild.load(str))
             {
                 i = 1;
                 forward();
                 return;
             }
-            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
-            lblInfo->setAlignment(Qt::AlignCenter);
-            lblInfo->setPixmap(bild);
-            i++;
+            else
+            {
+                bild = bild.scaled(w,h,Qt::KeepAspectRatio);
+                lblInfo->setAlignment(Qt::AlignCenter);
+                lblInfo->setPixmap(bild);
+                i++;
+            }
         //}
          return;
     }
@@ -333,17 +339,20 @@ void InfoWindow::back()
             str = "/home/user/.qexercise/Images/" + exerciseName + "2.png";
             str.replace(QString(" "), QString(""));
 
-            bild.load(str);
+
             if(!bild.load(str))
             {
                 i = 2;
                 back();
                 return;
             }
-            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
-            lblInfo->setAlignment(Qt::AlignCenter);
-            lblInfo->setPixmap(bild);
-            i=2;
+            else
+            {
+                bild = bild.scaled(w,h,Qt::KeepAspectRatio);
+                lblInfo->setAlignment(Qt::AlignCenter);
+                lblInfo->setPixmap(bild);
+                i=2;
+            }
         //}
          return;
     }
@@ -372,10 +381,13 @@ void InfoWindow::back()
                 back();
                 return;
             }
-            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
-            lblInfo->setAlignment(Qt::AlignCenter);
-            lblInfo->setPixmap(bild);
-            i--;
+            else
+            {
+                bild = bild.scaled(w,h,Qt::KeepAspectRatio);
+                lblInfo->setAlignment(Qt::AlignCenter);
+                lblInfo->setPixmap(bild);
+                i--;
+            }
         //}
         return;
 
