@@ -19,6 +19,11 @@ public:
     void load(QString name);
 
 signals:
+    void closed();
+    void landscape();
+
+public slots:
+    void sendClosed();
 
 private:
     WeightDialog *wd;
