@@ -29,12 +29,17 @@ private:
     QTextEdit *txtHowTo;
     QPushButton *btnSave;
     QMaemo5ValueButton *btnGroup;
+    QMaemo5ValueButton *btnPic2;
+    QMaemo5ValueButton *btnPic1;
     QMaemo5ListPickSelector *selectorGroup;
     QStandardItemModel *model;
 
+    QString pic1,pic2;
 private slots:
     void saveExercise();
     void orientationChanged();
+    void savePic2();
+    void savePic1();
 
 
 };
