@@ -11,11 +11,31 @@ WeightDialog::WeightDialog(QWidget *parent) :
     setWindowTitle("Save weight");
 
     QHBoxLayout *hLayout = new QHBoxLayout();
+    QVBoxLayout *buttonLayout = new QVBoxLayout();
 
-    lstVar = new QListView();
-    model = new QStandardItemModel(this);
-    lstVar->setModel(model);
-    hLayout->addWidget(lstVar);
+    modelReps = new QStandardItemModel(this);
+    for (int i = 1; i <= 25; i++)
+        modelReps->appendRow(new QStandardItem(tr("%1").arg(i)));
+
+    btnReps = new QMaemo5ValueButton("Reps");
+    btnReps->setValueLayout(QMaemo5ValueButton::ValueUnderText);
+    selectorReps = new QMaemo5ListPickSelector;
+    selectorReps->setModel(modelReps);
+    btnReps->setPickSelector(selectorReps);
+
+    modelVar = new QStandardItemModel(this);
+    for (int i = 1; i < 10; i++)
+        modelVar->appendRow(new QStandardItem(tr("%1").arg(i)));
+
+    btnVar = new QMaemo5ValueButton();
+    btnVar->setValueLayout(QMaemo5ValueButton::ValueUnderText);
+    selectorVar = new QMaemo5ListPickSelector;
+    selectorVar->setModel(modelVar);
+    btnVar->setPickSelector(selectorVar);
+
+    buttonLayout->addWidget(btnReps);
+    buttonLayout->addWidget(btnVar);
+    hLayout->addLayout(buttonLayout);
 
 
 
@@ -39,65 +59,53 @@ WeightDialog::WeightDialog(QWidget *parent) :
     connect(btnSave, SIGNAL(clicked()),this,SLOT(save()));
 }
 
-void WeightDialog::load(QString name, QString grp, QString currentReps)
+void WeightDialog::load(QString name, QString grp, QString currentSet)
 {
+    btnVar->setText("Weight");
     QList <QString> list;
-    int end;
+
     exName = name;
     group = grp;
-    reps = currentReps;
+    set = currentSet;
 
     for (int i = 1; i < 200; i++)
-        model->appendRow(new QStandardItem(tr("%1").arg(i)+ "kg"));
+        modelVar->appendRow(new QStandardItem(tr("%1").arg(i)+ "kg"));
 
     list = xml->openEx(name);
 
-    if(currentReps == "Low")
-        end = 4;
-    else if(currentReps == "Mid")
-        end = 5;
-    else
-        end = 6;
-    for(int i = 0; i < end; i++)
-        list.removeFirst();
 
-    QModelIndex index = model->index(list.takeFirst().toInt(),0);
-    lstVar->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select);
 
 
 
     setWindowTitle("Save weight");
 
-    //ViktDialog::ui->lstKg->setCurrentItem(ViktDialog::ui->lstKg->findItems("65",Qt::MatchExactly).takeFirst());//,QItemSelectionModel::Select);
+
 }
 
 void WeightDialog::loadCardio(QString name, QString m, QString s)
 {
+    btnReps->setEnabled(false);
+    btnVar->setText("Distance");
     QList <QString> list;
-    int end, select;
+    int select;
+
     group = "Cardio";
     exName = name;
     min = m;
     sec = s;
+    set = 1;
 
     for (double i = 1; i < 500; i++)
-        model->appendRow(new QStandardItem(tr("%1").arg(i/10) + "km"));
-
-    list = xml->openCardio(name);
-    list.removeFirst();
-
-    select = list.takeFirst().toDouble() * 10 - 1;
-    QModelIndex index = model->index(select,0);
-    lstVar->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select);
+        modelVar->appendRow(new QStandardItem(tr("%1").arg(i/10) + "km"));
 
     setWindowTitle("Save distance");
 
-    //ViktDialog::ui->lstKg->setCurrentItem(ViktDialog::ui->lstKg->findItems("65",Qt::MatchExactly).takeFirst());//,QItemSelectionModel::Select);
+
 }
 
 void WeightDialog::save()
 {
-    QString status;
+    QString status, weight;
     if(radioOK->isChecked())
         status = "perfect";
     else if(radioEasy->isChecked())
@@ -105,19 +113,29 @@ void WeightDialog::save()
     else if(radioHard->isChecked())
         status = "hard";
     else
-        status = "error";
+        return;
 
-    int l = lstVar->currentIndex().data().toString().count();
-    QString weight = lstVar->currentIndex().data().toString().left(l-2);
+    if(btnReps->valueText() == "")
+        return;
+    else if(btnVar->valueText() == "")
+        return;
 
+    weight = btnVar->valueText();
 
     if(group == "Cardio")
     {
         reps = min + ":" + sec;
         xml->updateLastDistance(exName, weight, min, sec, status);
     }
+    else
+    {
+        reps = btnReps->valueText();
+    }
 
-    xml->saveDoneEx(group, exName, weight, reps, status);
+    if(set.toInt() == 1)
+        xml->saveFirstSet(group, exName, weight, reps, status);
+    else
+        xml->updateHistory(exName,set,weight,reps,status);
 
     this->hide();
     emit next();
