@@ -3,7 +3,8 @@
 
 #include <QtGui>
 #include "xml.h"
-
+#include <QMaemo5ValueButton>
+#include <QMaemo5ListPickSelector>
 
 class WeightDialog : public QDialog
 {
@@ -29,12 +30,19 @@ private:
 
     QPushButton *btnSave;
 
-    QListView *lstVar;
+    QStandardItemModel *modelReps;
+    QStandardItemModel *modelVar;
+
+    QMaemo5ValueButton *btnReps;
+    QMaemo5ValueButton *btnVar;
+
+    QMaemo5ListPickSelector *selectorReps;
+    QMaemo5ListPickSelector *selectorVar;
+
 
-    QStandardItemModel *model;
     QString group;
     QString exName;
-    QString reps;
+    QString reps, set;
     QString min, sec;
 };
 #endif // WEIGHTDIALOG_H
